@@ -2,11 +2,12 @@ package Alien::GSL;
 
 use strict;
 use warnings;
+use 5.008001;
 
-our $VERSION = '1.00';
-$VERSION = eval $VERSION;
+our $VERSION = '1.05_01';
+$VERSION =~ tr/_//d;
 
-use parent 'Alien::Base';
+use base 'Alien::Base';
 
 1;
 
@@ -80,7 +81,7 @@ L<Math::GSL>
 
 =head1 SOURCE REPOSITORY
 
-L<https://github.com/Perl5-Alien/Alien-GSL>
+L<https://github.com/PerlAlien/Alien-GSL>
 
 =head1 AUTHOR
 
